Skip to contents

Strips out transformations from variable names in data frames

Usage

sanitizeNames(data)

Arguments

data

a data.frame

Value

a data frame with variable names cleaned to remove factor() construction