R/merData.R
stripAttributes.Rd
Strips attributes off of a data frame that come with a merMod model.frame
stripAttributes(data)
a data.frame
a data frame with variable names cleaned to remove all attributes except for names, row.names, and class