Extract the correlations between the slopes and the intercepts from a model
Source:R/merList.R
REcorrExtract.RdExtract the correlations between the slopes and the intercepts from a model
Examples
fm1 <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
REcorrExtract(fm1)
#> [1] 0.06555124