Extract the standard deviation of the random effects from a merMod object
Source:R/merList.R
REsdExtract.RdExtract the standard deviation of the random effects from a merMod object
Examples
fm1 <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
REsdExtract(fm1)
#> Subject.(Intercept) Subject.Days
#> 24.740658 5.922138